==> fbp-spec-0.6.0.tgz: package/lib/websocket.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var WebSocketRuntime, WebSocketServer;

WebSocketServer = require('websocket').server;

// XXX: Copied from https://github.com/noflo/noflo-runtime-websocket/blob/master/runtime/network.js
// should probably reuse it as-is
WebSocketRuntime = function () {
  function WebSocketRuntime() {
    var options1 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, WebSocketRuntime);

    this.options = options1;
    this.connections = [];
  }

  _createClass(WebSocketRuntime, [{
    key: 'send',
    value: function send(protocol, topic, payload, context) {
      if (!context.connection || !context.connection.connected) {
        return;
      }
      if (topic === 'error' && payload instanceof Error) {
        payload = {
          message: payload.message,
          stack: payload.stack
        };
      }
      context.connection.sendUTF(JSON.stringify({
        protocol: protocol,
        command: topic,
        payload: payload
      }));
    }
  }, {
    key: 'sendAll',
    value: function sendAll(protocol, topic, payload, context) {
      if (topic === 'error' && payload instanceof Error) {
        payload = {
          message: payload.message,
          stack: payload.stack
        };
      }
      this.connections.forEach(function (connection) {
        connection.sendUTF(JSON.stringify({
          protocol: protocol,
          command: topic,
          payload: payload
        }));
      });
    }
  }]);

  return WebSocketRuntime;
}();

module.exports = function (httpServer, options) {
  var handleMessage, runtime, wsServer;
  wsServer = new WebSocketServer({
    httpServer: httpServer
  });
  runtime = new WebSocketRuntime(options);
  handleMessage = function handleMessage(message, connection) {
    var contents, e;
    if (message.type === 'utf8') {
      contents = void 0;
      try {
        contents = JSON.parse(message.utf8Data);
      } catch (error) {
        e = error;
        if (e.stack) {
          console.error(e.stack);
        } else {
          console.error('Error: ' + e.toString());
        }
        return;
      }
      return runtime.receive(contents.protocol, contents.command, contents.payload, {
        connection: connection
      });
    }
  };
  wsServer.on('request', function (request) {
    var connection, subProtocol;
    subProtocol = request.requestedProtocols.indexOf('noflo') !== -1 ? 'noflo' : null;
    connection = request.accept(subProtocol, request.origin);
    runtime.connections.push(connection);
    connection.on('message', function (message) {
      return handleMessage(message, connection);
    });
    return connection.on('close', function () {
      if (runtime.connections.indexOf(connection) === -1) {
        return;
      }
      return runtime.connections.splice(runtime.connections.indexOf(connection), 1);
    });
  });
  return runtime;
};

==> fbp-spec-0.6.7.tgz: package/lib/websocket.js <==
"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var WebSocketRuntime, WebSocketServer;
WebSocketServer = require('websocket').server; // XXX: Copied from https://github.com/noflo/noflo-runtime-websocket/blob/master/runtime/network.js
// should probably reuse it as-is

WebSocketRuntime = /*#__PURE__*/function () {
  function WebSocketRuntime() {
    var options1 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, WebSocketRuntime);

    this.options = options1;
    this.connections = [];
  }

  _createClass(WebSocketRuntime, [{
    key: "send",
    value: function send(protocol, topic, payload, context) {
      if (!context.connection || !context.connection.connected) {
        return;
      }

      if (topic === 'error' && payload instanceof Error) {
        payload = {
          message: payload.message,
          stack: payload.stack
        };
      }

      context.connection.sendUTF(JSON.stringify({
        protocol: protocol,
        command: topic,
        payload: payload
      }));
    }
  }, {
    key: "sendAll",
    value: function sendAll(protocol, topic, payload, context) {
      if (topic === 'error' && payload instanceof Error) {
        payload = {
          message: payload.message,
          stack: payload.stack
        };
      }

      this.connections.forEach(function (connection) {
        connection.sendUTF(JSON.stringify({
          protocol: protocol,
          command: topic,
          payload: payload
        }));
      });
    }
  }]);

  return WebSocketRuntime;
}();

module.exports = function (httpServer, options) {
  var handleMessage, runtime, wsServer;
  wsServer = new WebSocketServer({
    httpServer: httpServer
  });
  runtime = new WebSocketRuntime(options);

  handleMessage = function handleMessage(message, connection) {
    var contents, e;

    if (message.type === 'utf8') {
      contents = void 0;

      try {
        contents = JSON.parse(message.utf8Data);
      } catch (error) {
        e = error;

        if (e.stack) {
          console.error(e.stack);
        } else {
          console.error('Error: ' + e.toString());
        }

        return;
      }

      return runtime.receive(contents.protocol, contents.command, contents.payload, {
        connection: connection
      });
    }
  };

  wsServer.on('request', function (request) {
    var connection, subProtocol;
    subProtocol = request.requestedProtocols.indexOf('noflo') !== -1 ? 'noflo' : null;
    connection = request.accept(subProtocol, request.origin);
    runtime.connections.push(connection);
    connection.on('message', function (message) {
      return handleMessage(message, connection);
    });
    return connection.on('close', function () {
      if (runtime.connections.indexOf(connection) === -1) {
        return;
      }

      return runtime.connections.splice(runtime.connections.indexOf(connection), 1);
    });
  });
  return runtime;
};
